@@ -18,6 +18,9 @@
  */
 
 
+#if HAVE_CONFIG_H
+#include <config.h>
+#endif
 
 #include <iostream>
 #include <algorithm>
@@ -25,7 +28,10 @@
 #include <boost/format.hpp>
 #include <boost/bind.hpp>
 
+#include <gtk/gtk.h>
+
 #include <glibmm/i18n.h>
+#include <glibmm/spawn.h>
 #include <gtkmm/icontheme.h>
 #include <gtkmm/image.h>
 #include <gtkmm/stock.h>
@@ -103,7 +109,7 @@ namespace gnote {
     Glib::RefPtr<Gdk::Pixbuf> get_icon(const std::string & name, int size)
     {
       try {
-        return Gtk::IconTheme::get_default()->load_icon(name, size);
+        return Gtk::IconTheme::get_default()->load_icon(name, size, (Gtk::IconLookupFlags) 0);
       }
       catch(const Glib::Exception & e)
       {
@@ -121,6 +127,7 @@ namespace gnote {
       }
       GError *error = NULL;
 
+#ifdef HAVE_GTK_SHOW_URI
       if(!gtk_show_uri (screen, uri.c_str(), gtk_get_current_event_time (), &error)) {
         
         std::string message = _("The \"Gnote Manual\" could "
@@ -138,8 +145,30 @@ namespace gnote {
           g_error_free(error);
         }
       }
+#else
+      Glib::spawn_command_line_async ("xdg-open " + uri);
+#endif
     }
 
+
+    void open_url(const std::string & url)
+      throw (Glib::Error)
+    {
+      if(!url.empty()) {
+        GError *err = NULL;
+        DBG_OUT("Opening url '%s'...", url.c_str());
+#ifdef HAVE_GTK_SHOW_URI
+        gtk_show_uri (NULL, url.c_str(), GDK_CURRENT_TIME, &err);
+#else
+        Glib::spawn_command_line_async ("xdg-open " + url);
+#endif
+        if(err) {
+          throw Glib::Error(err, true);
+        }
+      }
+    }
+
+
     void show_opening_location_error(Gtk::Window * parent, 
                                      const std::string & url, 
                                      const std::string & error)
@@ -177,21 +206,11 @@ namespace gnote {
           int num_days = now.day_of_year() - date.day_of_year();
           const char * fmt;
           if(show_time) {
-            if(num_days == 1) {
-              fmt = _("%1% day ago, %2%");
-            }
-            else {
-              fmt = _("%1% days ago, %2%");
-            }
+            fmt = ngettext("%1% day ago, %2%", "%1% days ago, %2%", num_days);
             pretty_str = str(boost::format(fmt) % num_days % short_time);
           }
           else {
-            if(num_days == 1) {
-              fmt = _("%1% day ago");
-            }
-            else {
-              fmt = _("%1% days ago");
-            }
+            fmt = ngettext("%1% day ago", "%1% days ago", num_days);
             pretty_str = str(boost::format(fmt) % num_days);
           }
         }
@@ -206,28 +225,18 @@ namespace gnote {
           int num_days = date.day_of_year() - now.day_of_year();
           const char * fmt;
           if(show_time) {
-            if(num_days == 1) {
-              fmt = _("In %1% day, %2%");
-            }
-            else {
-              fmt = _("In %1% days, %2%");
-            }
+            fmt = ngettext("In %1% day, %2%", "In %1% days, %2%", num_days);
             pretty_str = str(boost::format(fmt) % num_days % short_time); 
           }
           else {
-            if(num_days == 1) {
-              fmt = _("In %1% day");
-            }
-            else {
-              fmt = _("In %1% days");
-            }
+            fmt = ngettext("In %1% day", "In %1% days", num_days);
             pretty_str = str(boost::format(fmt) % num_days);
           }
         }
         else {
           pretty_str = show_time ?
-            date.to_string (_("%B %d, %H:%M %p")) : // "MMMM d, h:mm tt"
-            date.to_string (_("%B %d"));            // "MMMM d"
+            date.to_string ("%B %d, %H:%M %p") : // "MMMM d, h:mm tt"
+            date.to_string ("%B %d");            // "MMMM d"
         }
       } 
       else if (!date.is_valid()) {
@@ -235,8 +244,8 @@ namespace gnote {
       }
       else {
         pretty_str = show_time ?
-          date.to_string (_("%B %d %Y, %H:%M %p")) : // "MMMM d yyyy, h:mm tt"
-          date.to_string (_("%B %d %Y"));            // "MMMM d yyyy"
+          date.to_string ("%B %d %Y, %H:%M %p") : // "MMMM d yyyy, h:mm tt"
+          date.to_string ("%B %d %Y");            // "MMMM d yyyy"
       }
 
       return pretty_str;
@@ -443,6 +452,11 @@ namespace gnote {
     {
       std::vector<std::string> items;
       sharp::string_split(items, data, "\n");
+      load_from_string_list(items);
+    }
+
+    void UriList::load_from_string_list(const std::vector<std::string> & items)
+    {
       for(std::vector<std::string>::const_iterator iter = items.begin();
           iter != items.end(); ++iter) {
 
@@ -475,7 +489,7 @@ namespace gnote {
     UriList::UriList(const Gtk::SelectionData & selection)
     {
       if(selection.get_length() > 0) {
-        load_from_string(selection.get_text());
+        load_from_string_list(selection.get_uris());
       }
     }
 
